@@ -1,7 +1,7 @@
 
 /* pngset.c - storage of image information into info struct
  *
- * libpng 1.0.6e - April 9, 2000
+ * libpng 1.0.6i - May 1, 2000
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.
  * Copyright (c) 1996, 1997 Andreas Dilger
@@ -123,7 +123,9 @@ png_set_gAMA_fixed(png_structp png_ptr, png_infop info_ptr, png_fixed_point
 #ifdef PNG_FLOATING_POINT_SUPPORTED
    info_ptr->gamma = (float)(int_gamma/100000.);
 #endif
+#ifdef PNG_FIXED_POINT_SUPPORTED
    info_ptr->int_gamma = int_gamma;
+#endif
    info_ptr->valid |= PNG_INFO_gAMA;
 }
 
@@ -421,20 +423,29 @@ png_set_iCCP(png_structp png_ptr, png_infop info_ptr,
              png_charp name, int compression_type,
              png_charp profile, png_uint_32 proflen)
 {
+   png_charp new_iccp_name;
+   png_charp new_iccp_profile;
+
    png_debug1(1, "in %s storage function\n", "iCCP");
    if (png_ptr == NULL || info_ptr == NULL || name == NULL || profile == NULL)
       return;
 
+   new_iccp_name = png_malloc(png_ptr, png_strlen(name)+1);
+   strcpy(new_iccp_name, name);
+   new_iccp_profile = png_malloc(png_ptr, proflen);
+   png_memcpy(new_iccp_profile, profile, (png_size_t)proflen);
+
    png_free_data(png_ptr, info_ptr, PNG_FREE_ICCP, 0);
-   info_ptr->iccp_name = png_malloc(png_ptr, png_strlen(name)+1);
-   strcpy(info_ptr->iccp_name, name);
-   info_ptr->iccp_profile = png_malloc(png_ptr, proflen);
-   png_memcpy(info_ptr->iccp_profile, profile, (png_size_t)proflen);
+
    info_ptr->iccp_proflen = proflen;
+   info_ptr->iccp_name = new_iccp_name;
+   info_ptr->iccp_profile = new_iccp_profile;
    /* Compression is always zero but is here so the API and info structure
-    * does not have to change * if we introduce multiple compression types */
+    * does not have to change if we introduce multiple compression types */
    info_ptr->iccp_compression = (png_byte)compression_type;
+#ifdef PNG_FREE_ME_SUPPORTED
    info_ptr->free_me |= PNG_FREE_ICCP;
+#endif
    info_ptr->valid |= PNG_INFO_iCCP;
 }
 #endif
@@ -495,8 +506,14 @@ png_set_text(png_structp png_ptr, png_infop info_ptr, png_textp text_ptr,
       if(text_ptr[i].compression > 0)
       {
         /* set iTXt data */
-        lang_len = png_strlen(text_ptr[i].lang);
-        lang_key_len = png_strlen(text_ptr[i].lang_key);
+        if (text_ptr[i].key != (png_charp)NULL)
+          lang_len = png_strlen(text_ptr[i].lang);
+        else
+          lang_len = 0;
+        if (text_ptr[i].lang_key != (png_charp)NULL)
+          lang_key_len = png_strlen(text_ptr[i].lang_key);
+        else
+          lang_key_len = 0;
       }
       else
       {
@@ -504,7 +521,7 @@ png_set_text(png_structp png_ptr, png_infop info_ptr, png_textp text_ptr,
         lang_key_len = 0;
       }
 
-      if (text_ptr[i].text[0] == '\0')
+      if (text_ptr[i].text == (png_charp)NULL || text_ptr[i].text[0] == '\0')
       {
          text_length = 0;
          if(text_ptr[i].compression > 0)
@@ -538,19 +555,15 @@ png_set_text(png_structp png_ptr, png_infop info_ptr, png_textp text_ptr,
       }
       else
       {
-         textp->lang=NULL;
-         textp->lang_key=NULL;
+         textp->lang=(png_charp)NULL;
+         textp->lang_key=(png_charp)NULL;
          textp->text=textp->key + key_len + 1;
       }
 
       if(text_length)
-      {
          png_memcpy(textp->text, text_ptr[i].text,
             (png_size_t)(text_length));
-         *(textp->text+text_length) = '\0';
-      }
-      else
-         textp->text--;
+      *(textp->text+text_length) = '\0';
 
       if(textp->compression > 0)
       {
@@ -565,7 +578,9 @@ png_set_text(png_structp png_ptr, png_infop info_ptr, png_textp text_ptr,
 
       info_ptr->text[info_ptr->num_text]= *textp;
       info_ptr->num_text++;
+#ifdef PNG_FREE_ME_SUPPORTED
       info_ptr->free_me |= PNG_FREE_TEXT;
+#endif
       png_debug1(3, "transferred text chunk %d\n", info_ptr->num_text);
    }
 }
@@ -643,7 +658,9 @@ png_set_sPLT(png_structp png_ptr,
     info_ptr->splt_palettes = np;
     info_ptr->splt_palettes_num += nentries;
     info_ptr->valid |= PNG_INFO_sPLT;
+#ifdef PNG_FREE_ME_SUPPORTED
     info_ptr->free_me |= PNG_FREE_SPLT;
+#endif
 }
 #endif /* PNG_sPLT_SUPPORTED */
 
@@ -682,7 +699,17 @@ png_set_unknown_chunks(png_structp png_ptr,
 
     info_ptr->unknown_chunks = np;
     info_ptr->unknown_chunks_num += num_unknowns;
+#ifdef PNG_FREE_ME_SUPPORTED
     info_ptr->free_me |= PNG_FREE_UNKN;
+#endif
+}
+void
+png_set_unknown_chunk_location(png_structp png_ptr, png_infop info_ptr,
+   int chunk, int location)
+{
+   if(png_ptr != NULL && info_ptr != NULL && chunk >= 0 && chunk < 
+         (int)info_ptr->unknown_chunks_num)
+      info_ptr->unknown_chunks[chunk].location = (png_byte)location;
 }
 #endif
 
@@ -732,7 +759,9 @@ png_set_keep_unknown_chunks(png_structp png_ptr, int keep, png_bytep
        *p=(png_byte)keep;
     png_ptr->num_chunk_list=old_num_chunks+num_chunks;
     png_ptr->chunk_list=new_list;
+#ifdef PNG_FREE_ME_SUPPORTED
     png_ptr->free_me |= PNG_FREE_LIST;
+#endif
 }
 #endif
 
@@ -755,8 +784,21 @@ png_set_rows(png_structp png_ptr, png_infop info_ptr, png_bytepp row_pointers)
    if (png_ptr == NULL || info_ptr == NULL)
       return;
 
-   png_free_data(png_ptr, info_ptr, PNG_FREE_ROWS, 0);
-   info_ptr->row_pointers = row_pointers;
+   if(info_ptr->row_pointers != row_pointers)
+   {
+      png_free_data(png_ptr, info_ptr, PNG_FREE_ROWS, 0);
+      info_ptr->row_pointers = row_pointers;
+   }
 }
 #endif
 
+void
+png_set_compression_buffer_size(png_structp png_ptr, png_uint_32 size)
+{
+    if(png_ptr->zbuf)
+       png_free(png_ptr, png_ptr->zbuf);
+    png_ptr->zbuf_size = (png_size_t)size;
+    png_ptr->zbuf = (png_bytep)png_malloc(png_ptr, size);
+    png_ptr->zstream.next_out = png_ptr->zbuf;
+    png_ptr->zstream.avail_out = (uInt)png_ptr->zbuf_size;
+}
